@@ -6,11 +6,12 @@
 
 '''A simple Twitter client made with pyqt4'''
 
-__version__ = '0.1.10'
+__version__ = '0.1.11'
 
 #TODOS :
 #* Fix Identi.ca oauth bug
 #* Add separate notification for dm and mention
+#* Add list features
 #* Implements Twitpic
 #* Push 0.1.x line to extras
 #* Refactoring, Clean and Comment the code
@@ -277,7 +278,7 @@ class KhweeteurWin(QMainWindow):
 
         self.search_win = []
 
-        self.settings = QSettings()
+        self.settings = KhweeteurSettings()
 
         #Crappy fix for old prefs due to change to QVariant
         #Api 2 and PySide
